# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.118
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from helix_platform_api_public_client.api.attachment_api import AttachmentApi  # noqa: E501


class TestAttachmentApi(unittest.TestCase):
    """AttachmentApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AttachmentApi()  # noqa: E501

    def tearDown(self) -> None:
        pass

    def test_upload_attachment(self) -> None:
        """Test case for upload_attachment

        """
        pass


if __name__ == '__main__':
    unittest.main()
