# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.118
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List
from pydantic import BaseModel, Field, conlist
from helix_platform_api_public_client.models.nomination_gates_overview_response_day_ahead import NominationGatesOverviewResponseDayAhead
from helix_platform_api_public_client.models.nomination_gates_overview_response_intra_day import NominationGatesOverviewResponseIntraDay
from helix_platform_api_public_client.models.nomination_gates_overview_response_long_term import NominationGatesOverviewResponseLongTerm

class NominationGatesOverviewResponse(BaseModel):
    """
    NominationGatesOverviewResponse
    """
    long_term: NominationGatesOverviewResponseLongTerm = Field(..., alias="longTerm")
    day_ahead: NominationGatesOverviewResponseDayAhead = Field(..., alias="dayAhead")
    intra_day: conlist(NominationGatesOverviewResponseIntraDay) = Field(..., alias="intraDay")
    __properties = ["longTerm", "dayAhead", "intraDay"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> NominationGatesOverviewResponse:
        """Create an instance of NominationGatesOverviewResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of long_term
        if self.long_term:
            _dict['longTerm'] = self.long_term.to_dict()
        # override the default output from pydantic by calling `to_dict()` of day_ahead
        if self.day_ahead:
            _dict['dayAhead'] = self.day_ahead.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in intra_day (list)
        _items = []
        if self.intra_day:
            for _item in self.intra_day:
                if _item:
                    _items.append(_item.to_dict())
            _dict['intraDay'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> NominationGatesOverviewResponse:
        """Create an instance of NominationGatesOverviewResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return NominationGatesOverviewResponse.parse_obj(obj)

        _obj = NominationGatesOverviewResponse.parse_obj({
            "long_term": NominationGatesOverviewResponseLongTerm.from_dict(obj.get("longTerm")) if obj.get("longTerm") is not None else None,
            "day_ahead": NominationGatesOverviewResponseDayAhead.from_dict(obj.get("dayAhead")) if obj.get("dayAhead") is not None else None,
            "intra_day": [NominationGatesOverviewResponseIntraDay.from_dict(_item) for _item in obj.get("intraDay")] if obj.get("intraDay") is not None else None
        })
        return _obj


